nyxx library

Classes

ActionMetadata Models
Additional metadata associated with an AutoModerationAction.
ActionMetadataBuilder Builders
ActionRowBuilder Builders
ActionRowComponent Models
A Component that contains multiple child Components.
ActionType
The type of action for an AutoModerationAction.
Activity Models
A Rich Presence activity.
ActivityAssets Models
Information about an Activity's displayed assets.
ActivityBuilder Builders
ActivityButton Models
A button displayed in an activity.
ActivityFlags
Information about the data in an Activity instance.
ActivityParty Models
Information about an Activity's party.
ActivitySecrets Models
Information about an Activity's secrets.
ActivityTimestamps Models
Information about an Activity's timings.
ActivityType
The type of an activity.
AllowedMentions Builders
AnimationType
AnnouncementThread Entities Models
ApiOptions Core
Options for connecting to the Discord API.
Application Entities Models
An OAuth2 application.
ApplicationCommand Entities Models
A command that can be executed by users and is displayed in the Discord client UI.
ApplicationCommandAutocompleteInteraction
An application command autocomplete interaction.
ApplicationCommandBuilder Builders
ApplicationCommandInteraction Models
An application command interaction.
ApplicationCommandInteractionData Models
The data sent in an ApplicationCommandInteraction or an ApplicationCommandAutocompleteInteraction.
ApplicationCommandManager Managers
A Manager for ApplicationCommands.
ApplicationCommandPermissionsUpdateEvent Events
Emitted when the permissions for an application command are updated.
ApplicationCommandType
The type of an ApplicationCommand.
ApplicationCommandUpdateBuilder Builders
ApplicationEmojiBuilder Builders
ApplicationEmojiManager Managers
ApplicationEmojiUpdateBuilder Builders
ApplicationFlags
Flags for an Application.
ApplicationIntegrationType
ApplicationIntegrationTypeConfiguration Models
ApplicationIntegrationTypeConfigurationBuilder Builders
ApplicationManager Managers
A manager for Applications.
ApplicationRoleConnection Models
A role connection an application has attached to a user.
ApplicationRoleConnectionMetadata Models
Metadata for an app's role connections.
ApplicationRoleConnectionUpdateBuilder Builders
ApplicationUpdateBuilder Builders
Attachment Models
An attachment in a Message.
AttachmentBuilder Builders
AttachmentFlags
The flags for an Attachment.
AuditLogChange Models
A change to an object's field in an AuditLogEntry.
AuditLogEntry Entities Models
An entry in a Guild's audit log.
AuditLogEntryInfo Models
Extra information associated with an AuditLogEntry.
AuditLogEvent
The type of event an AuditLogEntry represents.
AuditLogManager Managers
AutoModerationAction Models
Describes an action to take when an AutoModerationRule is triggered.
AutoModerationActionBuilder Builders
AutoModerationActionExecutionEvent Events
Emitted when an auto moderation action is taken.
AutoModerationEventType
The type of event on which an AutoModerationRule triggers.
AutoModerationManager Managers
AutoModerationRule Entities Models
A rule use for auto-moderation in a Guild.
AutoModerationRuleBuilder Builders
AutoModerationRuleCreateEvent Events
Emitted when an auto moderation rule is created.
AutoModerationRuleDeleteEvent Events
Emitted when an auto moderation rule is deleted.
AutoModerationRuleUpdateBuilder Builders
AutoModerationRuleUpdateEvent Events
Emitted when an auto moderation rule is updated.
AvatarDecorationData Models
The data for the user's avatar decoration.
Ban Models
A ban in a Guild.
BaseRequest
The base class for HTTP requests.
BaseResponse
The base class for HTTP responses.
BasicRequest HTTP
An HttpRequest with a JSON body.
Builder<T> Core Builders
BulkBanResponse Models
ButtonBuilder Builders
ButtonComponent Models
A clickable button.
ButtonStyle
The style of a ButtonComponent.
Cache<T> Core
A simple cache for SnowflakeEntitys.
CacheConfig<T> Core
The configuration for a Cache instance.
CacheManager Core
A manager for all the caches associated with a client.
CdnAsset HTTP
An asset, most commonly an image, on Discord's CDN.
CdnRequest HTTP
A request to Discord's CDN.
Channel Entities Models
A channel of any type.
ChannelCreateEvent Events
Emitted when a channel is created.
ChannelDeleteEvent Events
Emitted when a channel is deleted.
ChannelFlags
A set of flags applied to channels.
ChannelInfo Events
Ephemeral information about channels in a Guild.
ChannelInfoEvent Events
Sent in response to a request channel info event.
ChannelManager Managers
A manager for Channels.
ChannelMention Models
A channel mentioned in a Message.
ChannelPinsUpdateEvent Events
Emitted when the pinned messages in a channel are changed.
ChannelPositionBuilder Builders
ChannelType
The type of a channel.
ChannelUpdateEvent Events
Emitted when a channel is updated.
CheckboxComponentBuilder Builders
CheckboxGroupComponentBuilder Builders
CheckboxGroupOptionBuilder Builders
ClientOptions Core
Options for controlling the behavior of a Nyxx client.
ClientStatus Models
The status of a client on multiple platforms.
CliIntegration Plugins
A plugin that lets clients close their session gracefully when the process is terminated.
CommandOption Models
An option in an ApplicationCommand with a type of ApplicationCommandType.chatInput.
CommandOptionBuilder Builders
CommandOptionChoice Models
A choice for a CommandOption.
CommandOptionChoiceBuilder<T> Builders
CommandOptionMentionable<T extends CommandOptionMentionable<T>> Entities
A common superclass for entities that can be passed in options of type CommandOptionType.mentionable.
CommandOptionType
The type of a CommandOption.
CommandPermission Models
The permission for a role, user or channel to use an ApplicationCommand.
CommandPermissions Entities Models
The permissions for an ApplicationCommand in a guild.
CommandPermissionType
The type of a CommandPermission.
Component Models
A component in a Message.
ComponentBuilder<T extends Component> Builders
ComponentType
The type of a Component.
Connection Models
A link to an account on a service other than Discord.
ConnectionMetadataType
The type of an ApplicationRoleConnectionMetadata.
ConnectionVisibility
The visibility level of a connection.
ContainerComponent Models
A component that contains several other components.
ContainerComponentBuilder Builders
CreateBuilder<T> Core Builders
Credentials
Credentials that prove that a client is allowed to access a resource on the resource owner's behalf.
CurrentMemberUpdateBuilder Builders
CurrentUserVoiceStateUpdateBuilder Builders
DefaultReaction Models
The emoji to show in the add reaction button on a thread in a ChannelType.guildForum or a ChannelType.guildMedia channel.
DefaultValue<T extends SnowflakeEntity<T>> Builders
DirectoryChannel Entities Models
A directory channel.
Disconnecting Gateway
A shard message sent when the shard is going to disconnect permanently.
DiscordColor Models
A 24-bit RGB color.
DispatchEvent Gateway Events
The base class for all events sent by dispatch.
Dispose Gateway
A gateway message sent to instruct the shard to disconnect & stop handling any further messages.
DmChannel Entities Models
A DM channel.
DmRecipientBuilder Builders
Embed Models
Rich content that can be embedded into a message, such as a video, image or custom text.
EmbedAuthor Models
An author for an Embed.
EmbedAuthorBuilder Builders
EmbedBuilder Builders
EmbedField Models
A field in an Embed.
EmbedFieldBuilder Builders
EmbedFlags
Flags that can be applied to an Embed.
EmbedFooter Models
A footer in an Embed.
EmbedFooterBuilder Builders
EmbedImage Models
An image in an Embed.
EmbedImageBuilder Builders
EmbedMediaFlags
Flags that can be applied to an EmbedThumbnail or an EmbedImage.
EmbedProvider Models
A provider for an Embed.
EmbedThumbnail Models
A thumbnail in an Embed.
EmbedThumbnailBuilder Builders
EmbedType
The type of an embed.
EmbedVideo Models
A video in an Embed.
Emoji Entities Models
An emoji. Either a TextEmoji, an ApplicationEmoji or a GuildEmoji.
EmojiBuilder Builders
EmojiManager Managers
EmojiUpdateBuilder Builders
Entitlement Entities Models
Premium access a user or guild has for an application.
EntitlementCreateEvent Events
Emitted when an entitlement is created.
EntitlementDeleteEvent Events
Emitted when an entitlement is deleted.
EntitlementManager Managers
A Manager for Entitlements.
EntitlementType
The type of an Entitlement.
EntitlementUpdateEvent Events
Emitted when an entitlement is updated.
EntityMetadata Models
Additional metadata associated with a ScheduledEvent.
EnumLike<T extends Object, U extends EnumLike<T, U>>
ErrorReceived Gateway
A shard message sent when the shard encounters an error.
EventParser Gateway
An internal class which allows the shard runner to parse gateway events without having a reference to the client's GatewayManager.
EventReceived Gateway
A shard message sent when an event is received on the Gateway.
EventStatus
The status of a ScheduledEvent.
ExplicitContentFilterLevel
The level of explicit content filtering in a guild.
FieldError HTTP
Information about an error associated with a specific field in a request.
FileComponent Models
A component that displays a downloadable file.
FileComponentBuilder Builders
FileUploadComponent Models
FileUploadComponentBuilder Builders
Flag<T extends Flags<T>>
A flag within a set of Flags.
Flags<T extends Flags<T>>
A set of flags that can be either enabled or disabled.
FollowedChannel Models
Information about a channel which has been followed.
FormDataRequest HTTP
ForumChannel Entities Models
A forum channel.
ForumChannelBuilder Builders
ForumChannelUpdateBuilder Builders
ForumLayout
The layout in a ForumChannel.
ForumSort
The sorting order in a ForumChannel.
ForumTag Models
A tag in a forum channel.
ForumTagBuilder Builders
ForumThreadBuilder Builders
Gateway Core Gateway
Handles the connection to Discord's Gateway with shards, manages the client's cache based on Gateway events and provides an interface to the Gateway.
GatewayApiOptions Core Gateway
Options for connecting to the Discord API for making HTTP requests and connecting to the Gateway with a bot token.
GatewayBot Gateway Models
Information about how to connect to the Gateway, with client-specific information.
GatewayClientOptions Core
Options for controlling the behavior of a NyxxGateway client.
GatewayConfiguration Models
Information about how to connect to the Gateway.
GatewayEvent Gateway Events
The base class for all events received from the Gateway.
GatewayIntents
Flags used to set the intents when opening a Gateway session.
GatewayManager Gateway Managers
A Manager for gateway information.
GatewayMessage Gateway
The base class for all control messages sent from the client to the shard.
GatewayVoiceStateBuilder Builders
GlobalApplicationCommandManager Managers
An ApplicationCommandManager for an application's global commands.
GlobalSoundboardManager Managers
GlobalSticker Entities Models
A sticker that can be sent in messages. Represents global stickers (default stickers)
GlobalStickerManager Managers
GroupDmChannel Entities Models
A DM channel with multiple recipients.
GroupDmUpdateBuilder Builders
Guild Entities Models
A collection of channels & users.
GuildAnnouncementChannel Entities Models
An announcement channel in a Guild.
GuildAnnouncementChannelBuilder Builders
GuildAnnouncementChannelUpdateBuilder Builders
GuildApplicationCommandManager Managers
An ApplicationCommandManager for the commands in a guild.
GuildAuditLogCreateEvent Events
Emitted when an audit log entry is created in a guild.
GuildBanAddEvent Events
Emitted when a user is banned in a guild.
GuildBanRemoveEvent Events
Emitted when a user is unbanned in a guild.
GuildBuilder Builders
GuildCategory Entities Models
A category for organizing other Channels in a Guild.
GuildCategoryBuilder Builders
GuildCategoryUpdateBuilder Builders
GuildChannel Entities Models
A channel in a Guild.
GuildChannelBuilder<T extends GuildChannel> Builders
GuildChannelUpdateBuilder<T extends GuildChannel> Builders
GuildCreateEvent Events
Emitted when a client is added to a guild or when initially receiving guilds over the Gateway.
GuildDeleteEvent Events
Emitted when the client is removed from a guild.
GuildEmoji Entities Models
A custom guild emoji.
GuildEmojiManager Managers
GuildEmojisUpdateEvent Events
Emitted when a guild's emojis are updated.
GuildFeatures
Features that can be enabled in certain guilds.
GuildIncidentsUpdateBuilder Builders
GuildIntegrationsUpdateEvent Events
Emitted when a guild's integrations are updated.
GuildInviteFlags
Flags for Invites.
GuildManager Managers
A manager for Guilds.
GuildMediaChannel Entities Models
A channel in a guild in which threads can be posted, similarly to a ForumChannel.
GuildMemberAddEvent Events
Emitted when a member joins a guild.
GuildMemberRemoveEvent Events
Emitted when a member is removed from a guild.
GuildMembersChunkEvent Events
Emitted as a response to Gateway.listGuildMembers.
GuildMemberUpdateEvent Events
Emitted when a guild member is updated.
GuildPreview Entities Models
A preview of a Guild.
GuildRoleCreateEvent Events
Emitted when a role is created in a guild.
GuildRoleDeleteEvent Events
Emitted when a role is deleted in a guild.
GuildRoleUpdateEvent Events
Emitted when a role is updated in a guild
GuildScheduledEventCreateEvent Events
Emitted when a scheduled event is created.
GuildScheduledEventDeleteEvent Events
Emitted when a scheduled event is deleted.
GuildScheduledEventUpdateEvent Events
Emitted when a scheduled event is updated.
GuildScheduledEventUserAddEvent Events
Emitted when a user is added to a scheduled event.
GuildScheduledEventUserRemoveEvent Events
Emitted when a user is removed from a scheduled event.
GuildSoundboardManager Managers
A Manager for guild SoundboardSounds.
GuildStageChannel Entities Models
A stage channel.
GuildStageChannelBuilder Builders
GuildStageChannelUpdateBuilder Builders
GuildSticker Entities Models
A sticker that can be sent in messages. Represent stickers added to guild
GuildStickerManager Managers
GuildStickersUpdateEvent Events
Emitted when a guild's stickers are updated.
GuildTemplate Models
A snapshot of a Guild that can be used to create a new guild.
GuildTemplateBuilder Builders
GuildTemplateUpdateBuilder Builders
GuildTextChannel Entities Models
A TextChannel in a Guild.
GuildTextChannelBuilder Builders
GuildTextChannelUpdateBuilder Builders
GuildUpdateBuilder Builders
GuildUpdateEvent Events
Emitted when a guild is updated.
GuildVoiceChannel Entities Models
A VoiceChannel in a Guild.
GuildVoiceChannelBuilder Builders
GuildVoiceChannelUpdateBuilder Builders
GuildWidget Models
A Guild's widget.
HasThreadsChannel Entities Models
A channel which can have threads.
HeartbeatAckEvent Events
Emitted when the server acknowledges the client's heartbeat.
HeartbeatEvent Events
Emitted when the client receives a request to heartbeat.
HelloEvent Events
Emitted when the client first establishes a connection to the gateway.
HttpBucket HTTP
A rate limit bucket tracking requests.
HttpErrorData HTTP
Information about an error from the API.
HttpHandler Core HTTP
A handler for making HTTP requests to the Discord API.
HttpRequest HTTP
An HTTP request to be made against the API.
HttpResponse HTTP
A response to a HttpRequest from the Discord API.
HttpResponseSuccess HTTP
A successful HttpResponse.
HttpRoute HTTP
A route within the Discord API.
HttpRouteParam HTTP
A parameter in a HttpRoutePart.
HttpRoutePart HTTP
A part of a HttpRoute.
Identify Gateway
A gateway message sent as a response to RequestingIdentify to allow the shard to identify.
IgnoreExceptions Plugins
A plugin that prevents errors from crashing the program, instead logging them to the console.
ImageBuilder Builders
IncidentsData Models
InstallationParameters Models
Configuration for an Application's authorization link.
Integration Entities Models
An integration in a Guild.
IntegrationAccount Models
Information about an integration's account.
IntegrationApplication Models
Information about an integration's application.
IntegrationCreateEvent Events
Emitted when an integration is created.
IntegrationDeleteEvent Events
Emitted when an integration is deleted.
IntegrationExpireBehavior
The behavior of an integration when a member's subscription expires.
IntegrationManager Managers
A Manager for Integrations.
IntegrationUpdateEvent Events
Emitted when an integration is updated.
Interaction<T> Models
An interaction sent by Discord when a user interacts with an ApplicationCommand, a Component or a ModalBuilder.
InteractionCallback Models
An interaction callback.
InteractionCallbackActivityInstanceResource Models
InteractionCallbackResponse Models
An interaction callback response.
InteractionCallbackType
InteractionContextType
A context indicating whether command can be used in DMs, groups, or guilds.
InteractionCreateEvent<T extends Interaction> Events
Emitted when an interaction is received by the client.
InteractionManager Managers
A Manager for Interactions.
InteractionOption Models
The value of a command option passed in an ApplicationCommandInteraction.
InteractionResource Models
An interaction resource.
InteractionResponseBuilder Builders
InteractionType
The type of an interaction.
InvalidSessionEvent Events
Emitted when the client's session is invalid.
Invite Models
An invite to a Guild or Channel. If the invite is to a Channel, this will be a GroupDmChannel.
InviteBuilder Builders
InviteCreateEvent Events
Emitted when an invite is created.
InviteDeleteEvent Events
Emitted when an invite is deleted.
InviteManager Managers
A manager for Invites.
InviteTargetsJobStatus Models
The status of processing the target users for an invite.
InviteTargetsJobStatusType
The type of an InviteTargetsJobStatus.
InviteType
The type of an Invite.
InviteWithMetadata Models
KeywordPresetType
A preset list of trigger keywords for an AutoModerationRule.
LabelComponentBuilder Builders
Level
Levels to control logging output. Logging can be enabled to include all levels above certain Level. Levels are ordered using an integer value Level.value. The predefined Level constants below are sorted as follows (in descending order): Level.SHOUT, Level.SEVERE, Level.WARNING, Level.INFO, Level.CONFIG, Level.FINE, Level.FINER, Level.FINEST, and Level.ALL.
Logger
Use a Logger to log debug messages.
Logging Plugins
A plugin that outputs a client's logs to stdout and stderr.
ManagedSnowflakeEntity<T extends ManagedSnowflakeEntity<T>> Core Entities
The base class for all SnowflakeEntity's that have a dedicated ReadOnlyManager.
Manager<T extends WritableSnowflakeEntity<T>> Core Managers
Provides the means to interact with the API for a given entity type.
MediaGalleryComponent Models
A component that displays several child media items.
MediaGalleryComponentBuilder Builders
MediaGalleryItem Models
An item in a MediaGalleryComponent.
MediaGalleryItemBuilder Builders
Member Entities Models
The representation of a User in a Guild.
MemberBuilder Builders
MemberFlags
Flags that can be applied to a Member.
MemberManager Managers
A manager for Members.
MemberUpdateBuilder Builders
Message Entities Models
Represents a message sent in a TextChannel.
MessageActivity Models
Activity data for rich presence related messages.
MessageActivityType
The type of a message activity.
MessageAuthor Models
An author of a message.
MessageBuilder Builders
MessageBulkDeleteEvent Events
Emitted when multiple messages are bulk deleted.
MessageCall Models
Information about a call in a private channel.
MessageComponentInteraction Models
A message component interaction.
MessageComponentInteractionData Models
The data sent in a MessageComponentInteraction.
MessageCreateEvent Events
Emitted when a message is sent.
MessageDeleteEvent Events
Emitted when a message is deleted.
MessageFlags
Flags that can be applied to a Message.
MessageInteraction Models
Information about an interaction associated with a message.
MessageInteractionMetadata Models
Metadata about the interaction, including the source of the interaction and relevant server and user IDs.
MessageManager Managers
A manager for Messages in a TextChannel.
MessageNotificationLevel
The level at which message notifications are sent in a guild.
MessagePin Models
Information about a pinned message.
MessagePollVoteAddEvent Events
Emitted when user votes on a poll. If the poll allows multiple selection, one event will be sent per answer.
MessagePollVoteRemoveEvent Events
Emitted when user removes their vote on a poll. If the poll allows for multiple selections, one event will be sent per answer.
MessageReactionAddEvent Events
Emitted when a reaction is added to a message.
MessageReactionRemoveAllEvent Events
Emitted when all reactions are removed from a message.
MessageReactionRemoveEmojiEvent Events
Emitted when all reactions of a specific emoji are removed from a message.
MessageReactionRemoveEvent Events
Emitted when a reaction is removed from a message.
MessageReference Models
A reference to an external entity contained in a message.
MessageReferenceBuilder Builders
MessageReferenceType
MessageSearchResult Models
The result of searching for messages within a Guild.
MessageSnapshot Models
A limited set of fields of a Message.
MessageType
The type of a message.
MessageUpdateBuilder Builders
MessageUpdateEvent Events
Emitted when a message is updated.
MfaLevel
The MFA level required for moderators of a guild.
ModalBuilder Builders
ModalSubmitInteraction Models
A modal submit interaction.
ModalSubmitInteractionData Models
The data sent in a ModalSubmitInteraction.
MultipartFile
A file to be uploaded as part of a MultipartRequest.
MultipartRequest HTTP
An HttpRequest with files & a JSON payload.
NitroType
The types of Discord Nitro subscription a user can have.
NsfwLevel
The NSFW level of a guild.
Nyxx Core
The base class for clients interacting with the Discord API.
NyxxGateway Core
A client that can make requests to the HTTP API, connects to the Gateway and is authenticated with a bot token.
NyxxOAuth2 Core
NyxxPlugin<ClientType extends Nyxx> Core Plugins
Provides access to the connection and closing process for implementing plugins.
NyxxPluginState<ClientType extends Nyxx, PluginType extends NyxxPlugin<ClientType>> Core Plugins
Holds the state of a plugin added to a client.
NyxxRest Core
A client that can make requests to the HTTP API and is authenticated with a bot token.
OAuth2ApiOptions Core
Options for connecting the the Discord API using credentials from an OAuth2 flow.
Oauth2HttpHandler HTTP
An HttpHandler that refreshes the OAuth2 access token if needed.
OAuth2Information Models
Onboarding Models
The configuration for a Guild's onboarding process.
OnboardingMode
The mode under which onboarding constraints operate when creating an Onboarding.
OnboardingPrompt Models
A prompt in an Onboarding flow.
OnboardingPromptBuilder Builders
OnboardingPromptOption Models
An option in an OnboardingPrompt.
OnboardingPromptOptionBuilder Builders
OnboardingPromptType
The type of an Onboarding prompt.
OnboardingUpdateBuilder Builders
PartialApplication Entities
A partial Application object.
PartialApplicationCommand Entities
A partial ApplicationCommand.
PartialAuditLogEntry Entities
A partial AuditLogEntry.
PartialAutoModerationRule Entities
A partial AutoModerationRule.
PartialChannel Entities
A partial Channel object.
PartialEmoji Entities
A partial Emoji object.
PartialEntitlement Entities
A partial Entitlement.
PartialGlobalSticker Entities
PartialGuild Entities
A partial Guild.
PartialGuildSticker Entities
PartialIntegration Entities
A partial Integration.
PartialMember Entities
A partial Member.
PartialMessage Entities
A partial Message object.
PartialRole Entities
A partial Role.
PartialScheduledEvent Entities
A partial ScheduledEvent.
PartialSku Entities
A partial Sku.
PartialSoundboardSound Entities
PartialSubscription Entities
A partial Subscription.
PartialTextChannel Entities
A partial TextChannel.
PartialThreadMember Models
A partial ThreadMember.
PartialUser Entities
A partial User object.
PartialWebhook Entities
A partial Webhook.
PermissionOverwrite Models
A set of overwrites to apply to permissions within a specific channel.
PermissionOverwriteBuilder Builders
PermissionOverwriteType
The type of a permission overwrite.
Permissions
A set of permissions.
PingInteraction Models
A ping interaction.
PinList Models
A list of MessagePins.
Poll Models
The poll object has a lot of levels and nested structures. It was also designed to support future extensibility, so some fields may appear to be more complex than necessary.
PollAnswer Models
The PollAnswer.id is a number that labels each answer. As an implementation detail, it currently starts at 1 for the first answer and goes up sequentially. We recommend against depending on this sequence.
PollAnswerBuilder Builders
External references:
PollAnswerCount Models
PollBuilder Builders
The poll object has a lot of levels and nested structures. It was also designed to support future extensibility, so some fields may appear to be more complex than necessary.
PollLayoutType
A layout type indicating how poll looks.
PollMedia Models
The poll media object is a common object that backs both the question and answers. The intention is that it allows us to extensibly add new ways to display things in the future. For now, Poll.question only supports PollMedia.text, while answers can have an optional PollMedia.emoji.
PollMediaBuilder Builders
The poll media object is a common object that backs both the question and answers. The intention is that it allows us to extensibly add new ways to display things in the future. For now, Poll.question only supports PollMedia.text, while answers can have an optional PollMedia.emoji.
PollResults Models
In a nutshell, this contains the number of votes for each answer. Due to the intricacies of counting at scale, while a poll is in progress the results may not be perfectly accurate. They usually are accurate, and shouldn't deviate significantly -- it's just difficult to make guarantees. To compensate for this, after a poll is finished there is a background job which performs a final, accurate tally of votes. This tally has concluded once PollResults.isFinalized is true. If PollResults.answerCounts does not contain an entry for a particular answer, then there are no votes for that answer.
PremiumTier
The premium tier of a guild.
PresenceBuilder Builders
PresenceUpdateEvent Events
Emitted when a user updates their presence.
PrivacyLevel
The privacy level of a StageInstance.
PrivateThread Entities Models
A private Thread channel.
PublicThread Entities Models
A public Thread channel.
RadioGroupComponentBuilder Builders
RadioGroupOptionBuilder Builders
RateLimitedEvent<T extends RateLimitedMetadata> Events
An event emitted when a Gateway request encounters a rate limit.
RateLimitedMetadata
Additional information about a rate limited Gateway request.
RawDispatchEvent Events
An unparsed dispatch event.
Reaction Models
A reaction to a message.
ReactionBuilder Builders
ReactionCountDetails Models
Details about a Reaction's Reaction.count.
ReadOnlyManager<T extends ManagedSnowflakeEntity<T>> Core Managers
A Manager that provides only read access to the API.
ReadyEvent Events
Emitted when the client's Gateway session is established.
ReconnectEvent Events
Emitted when the client receives a request to reconnect.
Reconnecting Gateway
A shard message sent when the shard needs to reconnect to the Gateway.
RecurrenceRule Models
Indicates how often a ScheduledEvent should recur.
RecurrenceRuleBuilder Builders
RecurrenceRuleFrequency
The frequency with which a ScheduledEvent can recur.
RecurrenceRuleMonth
The month on which a ScheduledEvent recurs.
RecurrenceRuleNWeekday Models
The week and weekday on which a ScheduledEvent recurs.
RecurrenceRuleWeekday
The weekday on which a ScheduledEvent recurs.
Request
An HTTP request where the entire request body is known in advance.
RequestGuildMemberRateLimitedMetadata Models
Additional information about a rate limited Opcode.requestGuildMembers Gateway request.
RequestingIdentify Gateway
A shard message sent when the shard is waiting to identify on the Gateway.
ResolvedData Models
A mapping of IDs to entities.
RestApiOptions Core
Options for connecting to the Discord API to make HTTP requests with a bot token.
RestClientOptions Core
Options for controlling the behavior of a NyxxRest client.
ResumedEvent Events
Emitted when the client resumes a Gateway session.
Role Entities Models
A role in a Guild.
RoleBuilder Builders
RoleColors Models
The colors for the Role.
RoleColorsBuilder Builders
RoleFlags
The flags for a Role.
RoleManager Managers
A manager for Roles.
RoleSubscriptionData Models
Information about a role subscription.
RoleTags Models
Additional metadata associated with a role.
RoleUpdateBuilder Builders
RuntimeType<T>
A non-opaque representation of a Type that can be used at runtime.
ScheduledEntityType
The type of the entity associated with a ScheduledEvent.
ScheduledEvent Entities Models
A scheduled event in a Guild.
ScheduledEventBuilder Builders
ScheduledEventManager Managers
A Manager for ScheduledEvents.
ScheduledEventUpdateBuilder Builders
ScheduledEventUser Models
A user that has followed a ScheduledEvent.
SectionComponent Models
A section in a message, with small accessory component.
SectionComponentBuilder Builders
SelectMenuBuilder Builders
SelectMenuComponent Models
A dropdown menu in which users can select from on or more choices.
SelectMenuDefaultValue Models
A default value in a SelectMenuComponent.
SelectMenuDefaultValueType
The type of a SelectMenuDefaultValue.
SelectMenuOption Models
An option in a SelectMenuComponent.
SelectMenuOptionBuilder Builders
Send Gateway
A gateway message sent to instruct the shard to send data on its connection.
Sent Gateway
A shard message sent when the shard adds a payload to the connection.
SeparatorComponent Models
A component that introduces space between two other components.
SeparatorComponentBuilder Builders
SeparatorSpacingSize
The size of the spacing introduced by a SeparatorComponent.
SessionStartLimit Models
Information about a client's session start limits.
Shard Gateway
A single connection to Discord's Gateway.
ShardData
Information a shard needs to run itself.
ShardMessage Gateway
The base class for all control messages sent from the shard to the client.
Sku Entities Models
A premium offering that can be made available to your application's users or guilds.
SkuFlags
Flags applied to an Sku.
SkuManager Managers
SkuType
The type of an Sku.
Snowflake Core Models
A unique ID used to identify objects in the API.
SnowflakeEntity<T extends SnowflakeEntity<T>> Core Entities
The base class for all entities in the API identified by a Snowflake.
SoundboardManager Managers
SoundboardSound Entities Models
SoundboardSoundBuilder Builders
SoundboardSoundCreateEvent Events
Emitted when a guild soundboard sound is created.
SoundboardSoundDeleteEvent Events
Emitted when a guild soundboard sound is deleted.
SoundboardSoundsEvent Events
Sent in response to a soundboard sounds request.
SoundboardSoundsUpdateEvent Events
Emitted when multiple guild soundboard sounds are updated.
SoundboardSoundUpdateBuilder Builders
SoundboardSoundUpdateEvent Events
Emitted when a guild soundboard sound is updated.
SoundBuilder Builders
StageInstance Entities Models
Information about a live stage.
StageInstanceBuilder Builders
A Stage Instance holds information about a live stage.
StageInstanceCreateEvent Events
Emitted when a stage instance is created.
StageInstanceDeleteEvent Events
Emitted when a stage instance is deleted.
StageInstanceUpdateBuilder Builders
StageInstanceUpdateEvent Events
Emitted when a stage instance is updated.
StartShard Gateway
A gateway message sent when the Gateway instance is ready for the shard to start.
StickerBuilder Builders
StickerFormatType
StickerItem Entities Models
A representation of a sticker with minimal information
StickerPack Entities Models
A Sticker Pack -- group of stickers that are gated behind Nitro.
StickerType
StickerUpdateBuilder Builders
StreamedResponse
An HTTP response where the response body is received asynchronously after the headers have been received.
SubmittedActionRowComponent Models
An ActionRowComponent received in an Interaction.
SubmittedCheckboxComponent Models
SubmittedCheckboxGroupComponent Models
SubmittedComponent Models
A component received as part of an Interaction.
SubmittedFileUploadComponent Models
SubmittedLabelComponent Models
A label received in an Interaction.
SubmittedRadioGroupComponent Models
SubmittedSelectMenuComponent Models
A SelectMenuComponent received in an Interaction.
SubmittedTextDisplayComponent Models
A TextDisplayComponent received in an Interaction.
SubmittedTextInputComponent Models
A text input received in an Interaction.
Subscription Entities Models
A subscription to an Sku.
SubscriptionCreateEvent Events
Sent when a Subscription is created.
SubscriptionDeleteEvent Events
Sent when a Subscription is deleted.
SubscriptionManager Managers
SubscriptionStatus
The status of a Subscription.
SubscriptionUpdateEvent Events
Sent when a Subscription is updated.
SystemChannelFlags
The configuration of a guild's system channel.
TargetType
The type of an Invite's target.
Team Models
A group of developers.
TeamMember Models
A member of a Team.
TeamMemberRole
The role of a TeamMember.
TeamMembershipState
The status of a member in a Team.
TestEntitlementBuilder Builders
TextChannel Entities Models
/ A text channel
TextDisplayComponent Models
A component that displays text.
TextDisplayComponentBuilder Builders
TextEmoji Entities Models
A text emoji, such as ❤️.
TextInputBuilder Builders
TextInputComponent Models
A text field in a modal.
TextInputStyle
The type of a SubmittedTextInputComponent.
Thread Entities Models
A thread channel.
ThreadBuilder Builders
ThreadCreateEvent Events
Emitted when a thread is created.
ThreadDeleteEvent Events
Emitted when a thread is deleted.
ThreadFromMessageBuilder Builders
ThreadList Models
A list of threads and thread members.
ThreadListSyncEvent Events
Emitted when the client's thread list is synced.
ThreadMember Models
Additional information associated with a Member in a Thread.
ThreadMembersUpdateEvent Events
Emitted when a members in a thread are updated.
ThreadMemberUpdateEvent Events
Emitted when the client's thread member is updated.
ThreadsOnlyChannel Entities Models
ThreadUpdateBuilder Builders
ThreadUpdateEvent Events
Emitted when a thread is updated.
ThumbnailComponent Models
A component that shows a small image.
ThumbnailComponentBuilder Builders
TriggerMetadata Models
Additional metadata associated with the trigger for an AutoModerationRule.
TriggerMetadataBuilder Builders
TriggerType
The type of a trigger for an AutoModerationRule
TypingStartEvent Events
Emitted when a user starts typing in a channel.
UnavailableGuildCreateEvent Events
Emitted when the client is added to an unavailable guild, or when initially receiving guilds over the Gateway.
UnfurledMediaItem Models
UnfurledMediaItemBuilder Builders
UnfurledMediaItemFlags
Flags that can be set on UnfurledMediaItems.
UnknownComponent Models
An unknown component.
UnknownDispatchEvent Events
Emitted when a RawDispatchEvent could not be parsed to a DispatchEvent due to the event being unknown.
UnknownInteraction Models
An unknown interaction.
UnknownRateLimitedMetadata Models
Unparsed information about a rate limited Gateway request.
UpdateBuilder<T> Core Builders
User Entities Models
A single user, outside of a Guild's context.
UserFlags
A set of Flags a user can have.
UserGuild Entities Models
A collection of channels & users.
UserManager Managers
A manager for Users.
UserPrimaryGuild Models
UserStatus
The status of a client.
UserUpdateBuilder Builders
UserUpdateEvent Events
Emitted when a user is updated.
VerificationLevel
The verification level for a guild.
VideoQualityMode
The quality mode of cameras in a VoiceChannel.
VoiceChannel Entities Models
A voice channel.
VoiceChannelEffectSendEvent Events
Emitted when someone sends an effect, such as an emoji reaction or a soundboard sound, in a voice channel the current user is connected to.
VoiceChannelStartTimeUpdateEvent Events
Emitted when a VoiceChannel updates its start time.
VoiceChannelStatusUpdateEvent Events
Emitted when a VoiceChannel updates its status.
VoiceManager Managers
A manager for VoiceStates.
VoiceRegion Models
A voice region.
VoiceServerUpdateEvent Events
Emitted when joining a voice channel to update the voice servers.
VoiceState Models
A user's voice connection state.
VoiceStateUpdateBuilder Builders
VoiceStateUpdateEvent Events
Emitted when a user's voice state is updated.
Webhook Entities Models
A non authenticated way to send messages to a Discord channel.
WebhookAuthor Models
A partial Webhook sent as part of a Message.
WebhookBuilder Builders
WebhookManager Managers
A manager for Webhooks.
WebhooksUpdateEvent Events
Emitted when the webhooks in a channel are updated.
WebhookType
The type of a Webhook.
WebhookUpdateBuilder Builders
WelcomeScreen Models
The configuration for the welcome screen in a guild.
WelcomeScreenChannel Models
A channel shown in a WelcomeScreen.
WelcomeScreenUpdateBuilder Builders
WidgetSettings Models
The settings for a Guild's widget.
WidgetSettingsUpdateBuilder Builders
WritableSnowflakeEntity<T extends WritableSnowflakeEntity<T>> Core Entities
The base class for all SnowflakeEntity's that have a dedicated Manager.

Enums

CdnFormat HTTP
Available formats for CDN endpoints.
ConnectionType
The type of a connection.
CurrentUserStatus
GatewayCompression
The compression of a Gateway connection.
GatewayPayloadFormat
The format of Gateway payloads.
Locale
A language locale available in the Discord client.
MessageAuthorType
The type of a message author.
MessageContentType
Content that may be present in a message.
MessageSearchOrder
The order in which messages are returned by a message search operation.
Opcode
Opcodes sent or received over the Gateway.
SearchEmbedType
The type of an Embed in a message search.
TestEntitlementType
WidgetImageStyle
The style of a guild widget image.

Mixins

MessageResponse<T>
ModalResponse<T>
Sticker Models
Mixin with shared properties with stickers

Properties

cliIntegration CliIntegration Plugins
A global instance of the CliIntegration plugin.
final
ignoreExceptions IgnoreExceptions Plugins
A global instance of the IgnoreExceptions plugin.
final
logging Logging Plugins
A global instance of the Logging plugin.
final

Typedefs

RateLimitInfo = ({Duration delay, bool isAnticipated, bool isGlobal, HttpRequest request}) HTTP
Information about a delay applied to request because of a rate limit.

Exceptions / Errors

AlreadyAcknowledgedError
An error thrown when MessageResponse.acknowledge is called on an already acknowledged interaction.
AlreadyRespondedError
An error thrown when MessageResponse.respond is called on an interaction that has already been responded to.
AuditLogEntryNotFoundException
An exception thrown when an audit log entry is not found in a guild.
ClientClosedError
An error thrown when the client is closed while an operation is pending, or when an already closed client is used.
EntitlementNotFoundException
An exception thrown when an entitlement is not found for an application.
HttpResponseError HTTP
An HttpResponse which represents an error from the API.
IntegrationNotFoundException
An exception thrown when a integration is not found in a guild.
InvalidEventException
An exception thrown when an unexpected event is received on the Gateway.
MemberAlreadyExistsException
An exception thrown when a member already exists in a guild.
NyxxException
The base class for all exceptions thrown by nyxx.
OutOfRemainingSessionsError Core
An error thrown when the number of remaining sessions becomes too low.
PluginError Plugins
An error thrown when an issue with a client's plugin is encountered.
RoleNotFoundException
An exception thrown when a role is not found in a guild.
ShardDisconnectedError Gateway
An error thrown when a shard disconnects unexpectedly.
SkuNotFoundException
An exception thrown when an SKU is not found for an application.
SoundboardSoundNotFoundException