ActionMetadata class Models

Additional metadata associated with an AutoModerationAction.

Implemented types

Properties

channel → PartialTextChannel?
The channel to send the alert message to.
no setter
channelId → Snowflake?
The ID of the channel to send the alert message to.
final
customMessage → String?
A custom message to send to the user.
final
duration → Duration?
The duration of time to time the user out for.
final
hashCode → int
The hash code for this object.
no setterinherited
manager → AutoModerationManager
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Map<String, Object?>
override
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited