ApplicationCommandBuilder class Builders

Inheritance

Constructors

ApplicationCommandBuilder({required String name, required ApplicationCommandType type, Map<Locale, String>? nameLocalizations, String? description, Map<Locale, String>? descriptionLocalizations, List<CommandOptionBuilder>? options, Flags<Permissions>? defaultMemberPermissions, bool? hasDmPermission, bool? isNsfw, List<ApplicationIntegrationType>? integrationTypes, List<InteractionContextType>? contexts})
ApplicationCommandBuilder.chatInput({required String name, Map<Locale, String>? nameLocalizations, required String description, Map<Locale, String>? descriptionLocalizations, required List<CommandOptionBuilder> options, Flags<Permissions>? defaultMemberPermissions, bool? hasDmPermission, bool? isNsfw, List<ApplicationIntegrationType>? integrationTypes, List<InteractionContextType>? contexts})
ApplicationCommandBuilder.message({required String name, Map<Locale, String>? nameLocalizations, Flags<Permissions>? defaultMemberPermissions, bool? hasDmPermission, bool? isNsfw, List<ApplicationIntegrationType>? integrationTypes, List<InteractionContextType>? contexts})
ApplicationCommandBuilder.user({required String name, Map<Locale, String>? nameLocalizations, Flags<Permissions>? defaultMemberPermissions, bool? hasDmPermission, bool? isNsfw, List<ApplicationIntegrationType>? integrationTypes, List<InteractionContextType>? contexts})

Properties

contexts ↔ List<InteractionContextType>?
Interaction context(s) where the command can be used, only for globally-scoped commands. By default, all interaction context types included.
getter/setter pair
defaultMemberPermissions ↔ Flags<Permissions>?
getter/setter pair
description ↔ String?
getter/setter pair
descriptionLocalizations ↔ Map<Locale, String>?
getter/setter pair
hasDmPermission ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integrationTypes ↔ List<ApplicationIntegrationType>?
Installation context(s) where the command is available, only for globally-scoped commands. Defaults to ApplicationIntegrationType.guildInstall.
getter/setter pair
isNsfw ↔ bool?
getter/setter pair
name ↔ String
getter/setter pair
nameLocalizations ↔ Map<Locale, String>?
getter/setter pair
options ↔ List<CommandOptionBuilder>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ApplicationCommandType
getter/setter pair

Methods

build() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited