BaseRequest class abstract

The base class for HTTP requests.

Subclasses of BaseRequest can be constructed manually and passed to BaseClient.send, which allows the user to provide fine-grained control over the request properties. However, usually it's easier to use convenience methods like get or BaseClient.get.

Subclasses/implementers should mixin/implement Abortable to support request cancellation. A future breaking version of 'package:http' will merge Abortable into BaseRequest, making it a requirement.

Constructors

BaseRequest(String method, Uri url)

Properties

contentLength int?
The size of the request body, in bytes.
getter/setter pair
finalized bool
Whether finalize has been called.
no setter
followRedirects bool
Whether the client should follow redirects while resolving this request.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
The HTTP headers sent to the server.
final
maxRedirects int
The maximum number of redirects to follow when followRedirects is true.
getter/setter pair
method String
The HTTP method of the request.
final
persistentConnection bool
Whether a persistent connection should be maintained with the server.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri
The URL to which the request will be sent.
final

Methods

finalize() → ByteStream
Finalizes the HTTP request in preparation for it being sent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send() Future<StreamedResponse>
Sends this request.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited