CdnFormat enum HTTP

Available formats for CDN endpoints.

Inheritance
Available extensions

Values

png → const CdnFormat

The PNG format.

const CdnFormat._('png')
jpeg → const CdnFormat

The JPEG/JPG format.

const CdnFormat._('jpeg')
webp → const CdnFormat

The webp format.

const CdnFormat._('webp')
gif → const CdnFormat

The GIF format.

This is only available to endpoints where CdnAsset.isAnimated is true.

const CdnFormat._('gif')
lottie → const CdnFormat

The Lottie format.

This is only available to sticker endpoints where Sticker.formatType is StickerFormatType.lottie.

const CdnFormat._('lottie')
mp3 → const CdnFormat

The mp3/ogg format.

This is only available to soundboard endpoints.

const CdnFormat._('')

Properties

extension String
The extension to use on the CDN endpoint for this format.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CdnFormat>
A constant List of the values in this enum, in order of their declaration.