ChannelPinsUpdateEvent class Events

Emitted when the pinned messages in a channel are changed.

Inheritance

Properties

channel → PartialTextChannel
The channel the pins were updated in.
no setter
channelId → Snowflake
The ID of the channel the pins were updated in.
final
gateway → Gateway
The gateway that handled this event.
finalinherited
guild → PartialGuild?
The guild the channel is in.
no setter
guildId → Snowflake?
The ID of the guild the channel is in.
final
hashCode → int
The hash code for this object.
no setterinherited
lastPinTimestamp → DateTime?
The time at which the last message was pinned.
final
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited