CheckboxComponentBuilder class Builders
- Inheritance
-
- Object
- Builder<
SubmittedCheckboxComponent> - CreateBuilder<
SubmittedCheckboxComponent> - ComponentBuilder<
SubmittedCheckboxComponent> - CheckboxComponentBuilder
Constructors
- CheckboxComponentBuilder({required String customId, bool? defaultValue, int? id})
Properties
- customId ↔ String
-
getter/setter pair
- defaultValue ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ ComponentType
-
getter/setter pairinherited
Methods
-
build(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited