CommandOption class Models

An option in an ApplicationCommand with a type of ApplicationCommandType.chatInput.

Properties

channelTypes → List<ChannelType>?
The types of channel that can be selected.
final
choices → List<CommandOptionChoice>?
The choices available for this option.
final
description → String
The description of this option.
final
descriptionLocalizations → Map<Locale, String>?
A localized map of descriptions for this option.
final
hasAutocomplete → bool?
Whether this option has autocompletion.
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
Whether this option is required.
final
maxLength → int?
The maximum length for this option.
final
maxValue → num?
The maximum value for this option.
final
minLength → int?
The minimum length for this option.
final
minValue → num?
The minimum value for this option.
final
name → String
The name of this option.
final
nameLocalizations → Map<Locale, String>?
A localized map of names for this option.
final
options → List<CommandOption>?
If this option is a subcommand, the options of the subcommand.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CommandOptionType
The type of this option.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited