CommandOptionMentionable<T extends CommandOptionMentionable<T>> class abstract interface Entities

A common superclass for entities that can be passed in options of type CommandOptionType.mentionable.

The only subtypes are User and Role.

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
fetch() → Future<T>
Fetch this entity from the API.
inherited
get() → Future<T>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited