ContainerComponent class Models

A component that contains several other components.

Inheritance

Properties

accentColor DiscordColor?
The accent color for this container.
final
components List<Component>
The components in this container.
final
hashCode int
The hash code for this object.
no setterinherited
id int
An identifier for this component.
finalinherited
isSpoiler bool?
Whether this container should be spoilered.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ComponentType
The type of this component.
no setteroverride

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited