FileComponent class Models

A component that displays a downloadable file.

Inheritance

Properties

file → UnfurledMediaItem
The file that can be downloaded.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
An identifier for this component.
finalinherited
isSpoiler → bool?
Whether the file should be spoilered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ComponentType
The type of this component.
no setteroverride

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited