GatewayClientOptions class
Options for controlling the behavior of a NyxxGateway client.
- Inheritance
-
- Object
- ClientOptions
- RestClientOptions
- GatewayClientOptions
Constructors
-
GatewayClientOptions({int minimumSessionStarts = 10, List<
NyxxPlugin< plugins = const [], String loggerName = 'Nyxx', Duration? rateLimitWarningThreshold = const Duration(seconds: 10), CacheConfig<Nyxx> >User> userCacheConfig = _smallCacheConfig, CacheConfig<Channel> channelCacheConfig = _defaultCacheConfig, CacheConfig<Message> messageCacheConfig = _smallCacheConfig, CacheConfig<Webhook> webhookCacheConfig = _defaultCacheConfig, CacheConfig<Guild> guildCacheConfig = _defaultCacheConfig, CacheConfig<Member> memberCacheConfig = _smallCacheConfig, CacheConfig<Role> roleCacheConfig = _defaultCacheConfig, CacheConfig<StageInstance> stageInstanceCacheConfig = _defaultCacheConfig, CacheConfig<ScheduledEvent> scheduledEventCacheConfig = _smallCacheConfig, CacheConfig<AutoModerationRule> autoModerationRuleConfig = _smallCacheConfig, CacheConfig<Integration> integrationConfig = _smallCacheConfig, CacheConfig<AuditLogEntry> auditLogEntryConfig = _smallCacheConfig, CacheConfig<VoiceState> voiceStateConfig = _smallCacheConfig, CacheConfig<ApplicationCommand> applicationCommandConfig = _defaultCacheConfig, CacheConfig<CommandPermissions> commandPermissionsConfig = _smallCacheConfig, CacheConfig<Entitlement> entitlementConfig = _defaultCacheConfig, CacheConfig<Sku> skuConfig = _defaultCacheConfig, CacheConfig<Emoji> emojiCacheConfig = _smallCacheConfig, CacheConfig<GlobalSticker> globalStickerCacheConfig = _defaultCacheConfig, CacheConfig<GuildSticker> stickerCacheConfig = _smallCacheConfig}) -
Create a new GatewayClientOptions.
const
Properties
-
applicationCommandConfig
→ CacheConfig<
ApplicationCommand> -
The CacheConfig to use for the
NyxxRest.commandsmanager.finalinherited -
auditLogEntryConfig
→ CacheConfig<
AuditLogEntry> -
The CacheConfig to use for the Guild.auditLogs manager.
finalinherited
-
autoModerationRuleConfig
→ CacheConfig<
AutoModerationRule> -
The CacheConfig to use for the Guild.autoModerationRules manager.
finalinherited
-
channelCacheConfig
→ CacheConfig<
Channel> -
The CacheConfig to use for the cache of the
NyxxRest.channelsmanager.finalinherited -
commandPermissionsConfig
→ CacheConfig<
CommandPermissions> -
The CacheConfig to use for the GuildApplicationCommandManager.permissionsCache cache.
finalinherited
-
emojiCacheConfig
→ CacheConfig<
Emoji> -
The CacheConfig to use for the Emojis in the Guild.emojis manager.
finalinherited
-
entitlementConfig
→ CacheConfig<
Entitlement> -
The CacheConfig to use for the Application.entitlements manager.
finalinherited
-
globalSoundboardCacheConfig
→ CacheConfig<
SoundboardSound> -
The CacheConfig to use for the
NyxxRest.soundboardmanager.finalinherited -
globalStickerCacheConfig
→ CacheConfig<
GlobalSticker> -
The CacheConfig to use for the GlobalStickers in the
NyxxRest.stickersmanager.finalinherited -
guildCacheConfig
→ CacheConfig<
Guild> -
The CacheConfig to use for the cache of the
NyxxRest.guildsmanager.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
integrationConfig
→ CacheConfig<
Integration> -
The CacheConfig to use for the Guild.integrations manager.
finalinherited
- logger → Logger
-
The logger to use for this client.
no setterinherited
- loggerName → String
-
The name of the logger to use for this client.
finalinherited
-
memberCacheConfig
→ CacheConfig<
Member> -
The CacheConfig to use for the Guild.members manager.
finalinherited
-
messageCacheConfig
→ CacheConfig<
Message> -
The CacheConfig to use for the cache of TextChannel.messages managers.
finalinherited
- minimumSessionStarts → int
-
The minimum number of session starts this client needs to connect.
final
-
plugins
→ List<
NyxxPlugin< Nyxx> > -
The plugins to use for this client.
finalinherited
- rateLimitWarningThreshold → Duration?
-
The threshold after which a warning will be logged if a request is waiting for rate limits.
finalinherited
-
roleCacheConfig
→ CacheConfig<
Role> -
The CacheConfig to use for the Guild.roles manager.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scheduledEventCacheConfig
→ CacheConfig<
ScheduledEvent> -
The CacheConfig to use for the Guild.scheduledEvents manager.
finalinherited
-
skuConfig
→ CacheConfig<
Sku> -
The CacheConfig to use for the Application.skus manager.
finalinherited
-
soundboardCacheConfig
→ CacheConfig<
SoundboardSound> -
The CacheConfig to use for the Guild.soundboard manager.
finalinherited
-
stageInstanceCacheConfig
→ CacheConfig<
StageInstance> -
The CacheConfig to use for StageInstances in the
NyxxRest.channelsmanager.finalinherited -
stickerCacheConfig
→ CacheConfig<
GuildSticker> -
The CacheConfig to use for the GuildStickers in the Guild.stickers manager.
finalinherited
-
subscriptionConfig
→ CacheConfig<
Subscription> -
The CacheConfig to use for the Sku.subscriptions manager.
finalinherited
-
userCacheConfig
→ CacheConfig<
User> -
The CacheConfig to use for the cache of the
NyxxRest.usersmanager.finalinherited -
voiceStateConfig
→ CacheConfig<
VoiceState> -
The CacheConfig to use for the PartialGuild.voiceStates cache.
finalinherited
-
webhookCacheConfig
→ CacheConfig<
Webhook> -
The CacheConfig to use for the cache of the
NyxxRest.webhooksmanager.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited