GuildUpdateBuilder class Builders

Inheritance

Constructors

GuildUpdateBuilder({String? name, VerificationLevel? verificationLevel, MessageNotificationLevel? defaultMessageNotificationLevel, ExplicitContentFilterLevel? explicitContentFilterLevel, Snowflake? afkChannelId = sentinelSnowflake, Duration? afkTimeout, ImageBuilder? icon = sentinelImageBuilder, Snowflake? newOwnerId, ImageBuilder? splash = sentinelImageBuilder, ImageBuilder? discoverySplash = sentinelImageBuilder, ImageBuilder? banner = sentinelImageBuilder, Snowflake? systemChannelId = sentinelSnowflake, Flags<SystemChannelFlags>? systemChannelFlags, Snowflake? rulesChannelId = sentinelSnowflake, Snowflake? publicUpdatesChannelId = sentinelSnowflake, Locale? preferredLocale, Flags<GuildFeatures>? features, String? description = sentinelString, bool? premiumProgressBarEnabled, Snowflake? safetyAlertsChannelId = sentinelSnowflake})

Properties

afkChannelId Snowflake?
The id of the afk channel.
getter/setter pair
afkTimeout Duration?
The afk timeout of the guild.
getter/setter pair
The banner of the guild.
getter/setter pair
defaultMessageNotificationLevel MessageNotificationLevel?
The default message notification level of the guild.
getter/setter pair
description String?
The description of the guild.
getter/setter pair
discoverySplash ImageBuilder?
The discovery splash of the guild.
getter/setter pair
explicitContentFilterLevel ExplicitContentFilterLevel?
The explicit content filter level of the guild.
getter/setter pair
features Flags<GuildFeatures>?
The features of the guild.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon ImageBuilder?
The icon of the guild.
getter/setter pair
name String?
The name of the guild. (2-100 characters)
getter/setter pair
newOwnerId Snowflake?
The id of the new owner of the guild.
getter/setter pair
preferredLocale Locale?
The preferred locale of the guild.
getter/setter pair
premiumProgressBarEnabled bool?
Whether the premium progress bar is enabled.
getter/setter pair
publicUpdatesChannelId Snowflake?
The id of the public updates channel.
getter/setter pair
rulesChannelId Snowflake?
The id of the rules channel.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyAlertsChannelId Snowflake?
getter/setter pair
splash ImageBuilder?
The splash of the guild.
getter/setter pair
systemChannelFlags Flags<SystemChannelFlags>?
The default system channel flags.
getter/setter pair
systemChannelId Snowflake?
The id of the channel where guild notices such as welcome messages and boost events are posted.
getter/setter pair
verificationLevel VerificationLevel?
The verification level of the guild.
getter/setter pair

Methods

build() Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited