HelloEvent class Events

Emitted when the client first establishes a connection to the gateway.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
heartbeatInterval → Duration
The interval at which the client should heartbeat.
final
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited