HttpRoute class HTTP

A route within the Discord API.

The path of a request made to the API is encoded as a HttpRoute. This allows for anticipation of rate limits based on the request's route.

External references:

Constructors

HttpRoute()

Properties

hashCode → int
The hash code for this object.
no setterinherited
parts → List<HttpRoutePart>
The HttpRouteParts that make up this route.
no setter
path → String
The path this HttpRoute represents, relative to Discord's root API URL.
no setter
rateLimitId → String
An id used for rate limiting.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → Iterable<String>
The segments of this route.
no setter

Methods

add(HttpRoutePart part) → void
Add part to this route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited