IntegrationManager class Managers

Inheritance

Constructors

IntegrationManager(CacheConfig<Integration> config, NyxxRest client, {required Snowflake guildId})
Create a new IntegrationManager.

Properties

cache → Cache<Integration>
The cache for this manager.
finalinherited
client → NyxxRest
The client this manager belongs to.
finalinherited
guildId → Snowflake
The ID of the guild this manager is for.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(Snowflake id, {String? auditLogReason}) → Future<void>
Delete an integration from the guild.
fetch(Snowflake id) → Future<Integration>
Fetch the item with the given id from the API.
override
get(Snowflake id) → Future<Integration>
Get an item by its id from the cache if it exists, else fetch it from the API.
inherited
list() → Future<List<Integration>>
List the integrations in the guild.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Map<String, Object?> raw) → Integration
Parse the raw data received from the API into an instance of the type of this manager.
override
parseIntegrationAccount(Map<String, Object?> raw) → IntegrationAccount
Parse an IntegrationAccount from raw.
parseIntegrationApplication(Map<String, Object?> raw) → IntegrationApplication
Parse an IntegrationApplication from raw.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Snowflake id) → PartialIntegration
Return a partial instance of the entity with ID id containing no data.
override