InteractionCallbackResponse class Models

An interaction callback response.

Properties

hashCode int
The hash code for this object.
no setterinherited
interaction InteractionCallback
The interaction object associated with the interaction response.
final
resource InteractionResource?
The resource that was created by the interaction response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited