attachments property
A list of files attached to this message.
The message content intent is needed for this field to be non-empty.
Implementation
@override
final List<Attachment> attachments;
A list of files attached to this message.
The message content intent is needed for this field to be non-empty.
@override
final List<Attachment> attachments;