MessageComponentInteraction class Models

A message component interaction.

Inheritance
Mixed-in types

Properties

applicationId → Snowflake
The ID of the application this interaction is for.
finalinherited
appPermissions → Permissions
The permissions of the application that triggered this interaction.
finalinherited
attachmentSizeLimit → int
Represents the maximun allowed size per-attachment for the given interaction
finalinherited
authorizingIntegrationOwners → Map<ApplicationIntegrationType, Snowflake>?
Mapping of installation contexts that the interaction was authorized for to related user or guild IDs.
finalinherited
channel → PartialChannel?
The channel this interaction was triggered in.
finalinherited
channelId → Snowflake?
The ID of the channel this interaction was triggered in.
finalinherited
context → InteractionContextType?
Context where the interaction was triggered from.
finalinherited
data → MessageComponentInteractionData
The data payload associated with this interaction.
finalinherited
entitlements → List<Entitlement>
The entitlements for the user and guild of this interaction.
finalinherited
guild → PartialGuild?
The guild in which this interaction was triggered.
no setterinherited
guildId → Snowflake?
The ID of the guild this interaction was triggered in.
finalinherited
guildLocale → Locale?
The preferred locale of the guild in which this interaction was triggered.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The ID of this interaction.
finalinherited
locale → Locale?
The preferred locale of the user that triggered this interaction.
finalinherited
manager → InteractionManager
The manager for this interaction.
finalinherited
member → Member?
The member that triggered this interaction.
finalinherited
message → Message?
The message this interaction was triggered on.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The token to use when responding to this interaction.
finalinherited
type → InteractionType
The type of this interaction.
finalinherited
user → User?
The user that triggered this interaction.
finalinherited
version → int
The interaction version.
finalinherited

Methods

acknowledge({bool? updateMessage, bool? isEphemeral, bool? withResponse}) → Future<InteractionCallbackResponse?>
Acknowledge this interaction.
override
createFollowup(MessageBuilder builder, {bool? isEphemeral}) → Future<Message>
Create a followup to this interaction.
inherited
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
deleteFollowup(Snowflake id) → Future<void>
Delete a followup to this interaction.
inherited
deleteOriginalResponse() → Future<void>
Delete the original response to this interaction.
inherited
fetchFollowup(Snowflake id) → Future<Message>
Fetch a followup to this interaction.
inherited
fetchOriginalResponse() → Future<Message>
Fetch the original response to this interaction.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
respond(Builder<Message> builder, {bool? updateMessage, bool? isEphemeral, bool? withResponse}) → Future<InteractionCallbackResponse?>
Send a response to this interaction.
override
respondModal(ModalBuilder builder) → Future<void>
Send a modal response to this interaction.
inherited
toString() → String
A string representation of this object.
inherited
updateFollowup(Snowflake id, MessageUpdateBuilder builder) → Future<Message>
Update a followup to this interaction.
inherited
updateOriginalResponse(MessageUpdateBuilder builder) → Future<Message>
Update the original response to this interaction.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited