MessagePollVoteRemoveEvent class Events

Emitted when user removes their vote on a poll. If the poll allows for multiple selections, one event will be sent per answer.

Inheritance

Properties

answerId int
The ID of the answer on the poll.
final
channel PartialTextChannel
The channel the message is in.
no setter
channelId Snowflake
The ID of the channel the message is in.
final
gateway Gateway
The gateway that handled this event.
finalinherited
guild PartialGuild?
The guild the message is in.
no setter
guildId Snowflake?
The ID of the guild the message is in.
final
hashCode int
The hash code for this object.
no setterinherited
member PartialMember?
The member that removed their vote from a poll.
no setter
message PartialMessage
The message where vote removed from a poll.
no setter
messageId Snowflake
The ID of the message where vote removed from a poll.
final
opcode Opcode
The opcode of this event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user PartialUser
The user that removed their vote from a poll.
no setter
userId Snowflake
The ID of the user that removed their vote from a poll.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited