MessageSearchResult class Models

The result of searching for messages within a Guild.

Properties

doingDeepHistoricalIndex bool
Whether the guild is undergoing a deep historical indexing operation.
final
hashCode int
The hash code for this object.
no setterinherited
indexedDocumentCount int?
The number of documents that have been indexed during the current index operation, if any.
final
messages List<Message>
The messages that match the query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadMembers List<ThreadMember>
A thread member object for each returned thread the current user has joined.
final
threads List<Thread>
The threads that contain the returned messages.
final
totalResults int
The total number of results that match the query.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited