Opcode enum
Opcodes sent or received over the Gateway.
Values
- dispatch → const Opcode
-
An event is dispatched to the client.
const Opcode._(0) - heartbeat → const Opcode
-
Sent when heartbeating or received when requesting a heartbeat.
const Opcode._(1) - identify → const Opcode
-
Sent when opening a Gateway session.
const Opcode._(2) - presenceUpdate → const Opcode
-
Sent when updating the client's presence.
const Opcode._(3) - voiceStateUpdate → const Opcode
-
Sent when updating the client's voice state.
const Opcode._(4) - resume → const Opcode
-
Send when resuming a Gateway session.
const Opcode._(6) - reconnect → const Opcode
-
Received when the client should reconnect.
const Opcode._(7) - requestGuildMembers → const Opcode
-
Sent to request guild members.
const Opcode._(8) - invalidSession → const Opcode
-
Received when the client's session is invalid.
const Opcode._(9) - hello → const Opcode
-
Received when the connection to the Gateway is opened.
const Opcode._(10) - heartbeatAck → const Opcode
-
Received when the server receives the client's heartbeat.
const Opcode._(11) - requestSoundboardSounds → const Opcode
-
Sent to request information about soundboard sounds.
const Opcode._(31) - requestChannelInfo → const Opcode
-
Sent to request ephemeral channel information.
const Opcode._(43)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The value of this Opcode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited