PartialGuild class Entities

A partial Guild.

Inheritance
Implementers

Properties

auditLogs → AuditLogManager
An AuditLogManager for the audit log of this guild.
no setter
autoModerationRules → AutoModerationManager
An AutoModerationManager for the auto moderation rules of this guild.
no setter
commands → GuildApplicationCommandManager
A GuildApplicationCommandManager for the application commands of this guild.
no setter
emojis → GuildEmojiManager
A GuildEmojiManager for the emojis of this guild.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
integrations → IntegrationManager
An IntegrationManager for the integrations of this guild.
no setter
manager → GuildManager
The manager for this entity.
final
members → MemberManager
A MemberManager for the members of this guild.
no setter
roles → RoleManager
A RoleManager for the roles of this guild.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledEvents → ScheduledEventManager
A ScheduledEventManager for the scheduled events of this guild.
no setter
soundboard → GuildSoundboardManager
A GuildSoundboardManager for the soundboard sounds of this guild.
no setter
stickers → GuildStickerManager
An GuildStickerManager for the stickers of this guild.
no setter
voiceStates → Cache<VoiceState>
A Cache for VoiceStates in this guild.
no setter

Methods

bulkBan(List<Snowflake> userIds, {Duration? deleteMessages, String? auditLogReason}) → Future<BulkBanResponse>
Ban up to 200 users from a guild, and optionally delete previous messages sent by the banned users.
createBan(Snowflake userId, {Duration? deleteMessages, String? auditLogReason}) → Future<void>
Ban a user in this guild.
createChannel<T extends GuildChannel>(GuildChannelBuilder<T> builder, {String? auditLogReason}) → Future<T>
Create a channel in this guild.
createTemplate(GuildTemplateBuilder builder) → Future<GuildTemplate>
Create a template in this guild.
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete() → Future<void>
Delete this entity.
inherited
deleteBan(Snowflake userId, {String? auditLogReason}) → Future<void>
Unban a user in this guild.
deleteTemplate(String code) → Future<GuildTemplate>
Delete a template in this guild.
fetch({bool? withCounts}) → Future<Guild>
Fetch this entity from the API.
override
fetchChannels() → Future<List<GuildChannel>>
Fetch the channels in this guild.
fetchCurrentMember() → Future<Member>
Fetch the current user's member in this guild.
fetchOnboarding() → Future<Onboarding>
Fetch the onboarding information for this guild.
fetchPreview() → Future<GuildPreview>
Fetch this guild's preview.
fetchPruneCount({int? days, List<Snowflake>? roleIds}) → Future<int>
Fetch the member prune count for the given days and roleIds.
fetchVanityCode() → Future<String?>
Fetch this guild's vanity invite code.
fetchWelcomeScreen() → Future<WelcomeScreen>
Fetch this guild's welcome screen.
fetchWidget() → Future<GuildWidget>
Fetch this guild's widget information.
fetchWidgetImage({WidgetImageStyle? style}) → Future<Uint8List>
Fetch this guild's widget image.
fetchWidgetSettings() → Future<WidgetSettings>
Fetch this guild's widget settings.
get() → Future<Guild>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
leave() → Future<void>
Leave this guild.
listActiveThreads() → Future<ThreadList>
List the active threads in this guild.
listBans({int? limit, Snowflake? after, Snowflake? before}) → Future<List<Ban>>
List the bans in this guild.
listInvites() → Future<List<Invite>>
List the invites to this guild.
listTemplates() → Future<List<GuildTemplate>>
List the templates in this guild.
listVoiceRegions() → Future<List<VoiceRegion>>
List the voice regions available in the guild.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchMessages({int? limit, int? offset, Snowflake? maxId, Snowflake? minId, int? slop, String? content, List<Snowflake>? channelIds, List<MessageAuthorType>? includeAuthorTypes, List<MessageAuthorType>? excludeAuthorTypes, List<Snowflake>? authorIds, List<Snowflake>? mentionIds, List<Snowflake>? mentionRoleIds, bool? mentionsEveryone, List<Snowflake>? repliedToUserIds, List<Snowflake>? repliedToMessageIds, bool? isPinned, List<MessageContentType>? includeMessagesWith, List<MessageContentType>? excludeMessagesWith, List<SearchEmbedType>? hasEmbeds, List<String>? embedProviders, List<String>? linkHostnames, List<String>? attachmentFilenames, List<String>? attachmentExtensions, MessageSearchOrder? sortBy, bool? ascending, bool? includeNsfw, bool retryIfIndexing = true}) → Future<MessageSearchResult>
Search for messages within this guild.
startPrune({int? days, bool? computeCount, List<Snowflake>? roleIds, String? auditLogReason}) → Future<int?>
Start a member prune with the given days and roleIds.
syncTemplate(String code) → Future<GuildTemplate>
Sync a template in this guild.
toString() → String
A string representation of this object.
inherited
update(covariant UpdateBuilder<Guild> builder) → Future<Guild>
Update this entity using the provided builder and return the updated entity.
inherited
updateChannelPositions(List<ChannelPositionBuilder> positions) → Future<void>
Update the channel positions in this guild.
updateCurrentUserVoiceState(CurrentUserVoiceStateUpdateBuilder builder) → Future<void>
Update the current user's voice state in this guild.
updateMfaLevel(MfaLevel level, {String? auditLogReason}) → Future<MfaLevel>
Update a guild's MFA level.
updateOnboarding(OnboardingUpdateBuilder builder, {String? auditLogReason}) → Future<Onboarding>
Update this guild's onboarding.
updateTemplate(String code, GuildTemplateUpdateBuilder builder) → Future<GuildTemplate>
Update a template in this guild.
updateVoiceState(Snowflake userId, VoiceStateUpdateBuilder builder) → Future<void>
Update a member's voice state in this guild.
updateWelcomeScreen(WelcomeScreenUpdateBuilder builder, {String? auditLogReason}) → Future<WelcomeScreen>
Update this guild's welcome screen.
updateWidgetSettings(WidgetSettingsUpdateBuilder builder, {String? auditLogReason}) → Future<WidgetSettings>
Update this guild's widget settings.

Operators

operator ==(Object other) → bool
The equality operator.
inherited