PinList class Models

A list of MessagePins.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
Whether more results can be queried.
final
items → List<MessagePin>
The pins this channel has.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited