PollAnswerBuilder class Builders
External references:
- Discord API Reference: https://discord.com/developers/docs/resources/poll#poll-answer-object
- Inheritance
-
- Object
- Builder<
PollAnswer> - CreateBuilder<
PollAnswer> - PollAnswerBuilder
Constructors
- PollAnswerBuilder({required PollMediaBuilder pollMedia})
- PollAnswerBuilder.text(String text, [Emoji? emoji])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pollMedia ↔ PollMediaBuilder
-
The data of the answer.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited