RateLimitInfo typedef HTTP
Information about a delay applied to request because of a rate limit.
isGlobal indicates if the delay applied is due to the global rate limit.
isAnticipated will be true if the request was delayed before it was sent. If isAnticipated is false,
a response with the status code 429 was received from the API.
Implementation
typedef RateLimitInfo = ({HttpRequest request, Duration delay, bool isGlobal, bool isAnticipated});