SnowflakeEntity<T extends SnowflakeEntity<T>> class abstract Core Entities

The base class for all entities in the API identified by a Snowflake.

Implementers

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → Snowflake
The id of this entity.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
fetch() → Future<T>
Fetch this entity from the API.
get() → Future<T>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override