SoundboardSoundUpdateEvent class
Emitted when a guild soundboard sound is updated.
- Inheritance
-
- Object
- GatewayEvent
- DispatchEvent
- SoundboardSoundUpdateEvent
Properties
- gateway → Gateway
-
The gateway that handled this event.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- oldSound → SoundboardSound?
-
The old sound.
final
- opcode → Opcode
-
The opcode of this event.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → SoundboardSound
-
The sound that was updated.
final
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited