SoundboardSoundsUpdateEvent class Events

Emitted when multiple guild soundboard sounds are updated.

Inheritance

Properties

gateway Gateway
The gateway that handled this event.
finalinherited
guild PartialGuild
The guild the sounds are for.
no setter
guildId Snowflake
The ID of the guild where the sounds were updated.
final
hashCode int
The hash code for this object.
no setterinherited
oldSounds List<SoundboardSound?>
The old sounds.
final
opcode Opcode
The opcode of this event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sounds List<SoundboardSound>
The sounds that were updated.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited