SubmittedCheckboxComponent class Models

Inheritance

Properties

customId → String
The custom id for this component.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
An identifier for this component.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ComponentType
The type of this component.
no setteroverride
value → bool
Whether the checkbox is selected.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited