SubscriptionUpdateEvent class Events

Sent when a Subscription is updated.

Inheritance

Properties

gateway → Gateway
The gateway that handled this event.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
oldSubscription → Subscription?
The subscription before it was updated, if it was cached.
final
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → Subscription
The new subscription.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited