SystemChannelFlags class

The configuration of a guild's system channel.

Inheritance

Constructors

SystemChannelFlags(int value)
Create a new SystemChannelFlags.
const

Properties

first → Flag<SystemChannelFlags>
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<Flag<SystemChannelFlags>>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last → Flag<SystemChannelFlags>
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldSuppressGuildReminderNotifications → bool
Whether this configuration has the suppressGuildReminderNotifications flag.
no setter
shouldSuppressJoinNotificationReplies → bool
Whether this configuration has the suppressJoinNotificationReplies flag.
no setter
shouldSuppressJoinNotifications → bool
Whether this configuration has the suppressJoinNotifications flag.
no setter
shouldSuppressPremiumSubscriptions → bool
Whether this configuration has the suppressPremiumSubscriptions flag.
no setter
shouldSuppressRoleSubscriptionPurchaseNotificationReplies → bool
Whether this configuration has the suppressRoleSubscriptionPurchaseNotificationReplies flag.
no setter
shouldSuppressRoleSubscriptionPurchaseNotifications → bool
Whether this configuration has the suppressRoleSubscriptionPurchaseNotifications flag.
no setter
single → Flag<SystemChannelFlags>
Checks that this iterable has only one element, and returns that element.
no setterinherited
value → int
The integer value encoding the flags as a bitfield.
finalinherited

Methods

any(bool test(Flag<SystemChannelFlags> element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
elementAt(int index) → Flag<SystemChannelFlags>
Returns the indexth element.
inherited
every(bool test(Flag<SystemChannelFlags> element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Flag<SystemChannelFlags> element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Flag<SystemChannelFlags> element), {Flag<SystemChannelFlags> orElse()?}) → Flag<SystemChannelFlags>
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Flag<SystemChannelFlags> element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Flag<SystemChannelFlags>> other) → Iterable<Flag<SystemChannelFlags>>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Flag<SystemChannelFlags> element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
has(Flag<SystemChannelFlags> flag) → bool
Returns true if this Flags has the flag enabled, false otherwise.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Flag<SystemChannelFlags> element), {Flag<SystemChannelFlags> orElse()?}) → Flag<SystemChannelFlags>
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Flag<SystemChannelFlags> e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(Flag<SystemChannelFlags> combine(Flag<SystemChannelFlags> value, Flag<SystemChannelFlags> element)) → Flag<SystemChannelFlags>
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(Flag<SystemChannelFlags> element), {Flag<SystemChannelFlags> orElse()?}) → Flag<SystemChannelFlags>
The single element that satisfies test.
inherited
skip(int count) → Iterable<Flag<SystemChannelFlags>>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Flag<SystemChannelFlags> element)) → Iterable<Flag<SystemChannelFlags>>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<Flag<SystemChannelFlags>>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Flag<SystemChannelFlags> element)) → Iterable<Flag<SystemChannelFlags>>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<Flag<SystemChannelFlags>>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<Flag<SystemChannelFlags>>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
inherited
where(bool test(Flag<SystemChannelFlags> element)) → Iterable<Flag<SystemChannelFlags>>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator &(Flags<SystemChannelFlags> other) → Flags<SystemChannelFlags>
Return a set of flags that has all the flags set in both this and other.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator ^(Flags<SystemChannelFlags> other) → Flags<SystemChannelFlags>
Return a set of flags that has all the flags set in this or in other but not in both.
inherited
operator |(Flags<SystemChannelFlags> other) → Flags<SystemChannelFlags>
Return a set of flags that has all the flags set in either this or other.
inherited
operator ~() → Flags<SystemChannelFlags>
Returns the opposite of this set of flags.
inherited

Constants

suppressGuildReminderNotifications → const Flag<SystemChannelFlags>
Suppress server setup tips.
suppressJoinNotificationReplies → const Flag<SystemChannelFlags>
Hide member join sticker reply buttons.
suppressJoinNotifications → const Flag<SystemChannelFlags>
Suppress member join notifications.
suppressPremiumSubscriptions → const Flag<SystemChannelFlags>
Suppress server boost notifications.
suppressRoleSubscriptionPurchaseNotificationReplies → const Flag<SystemChannelFlags>
Hide role subscription sticker reply buttons.
suppressRoleSubscriptionPurchaseNotifications → const Flag<SystemChannelFlags>
Suppress role subscription purchase and renewal notifications.