TextDisplayComponent class Models

A component that displays text.

Inheritance

Properties

content String
The content of this section.
final
hashCode int
The hash code for this object.
no setterinherited
id int
An identifier for this component.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ComponentType
The type of this component.
no setteroverride

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited