ThreadMember class Models

Additional information associated with a Member in a Thread.

Inheritance

Properties

flags → Flags<Never>
Internal flags used by Discord for notification purposes.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
joinTimestamp → DateTime
The time at which this member joined the thread.
finalinherited
manager → ChannelManager
The manager for this ThreadMember.
final
member → Member?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thread → PartialTextChannel
The thread this member is in.
no setter
threadId → Snowflake
The ID of the thread this member is in.
final
user → PartialUser
The user associated with this thread member.
no setter
userId → Snowflake
The ID of the user associated with this thread member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited