VoiceChannelStartTimeUpdateEvent class Events

Emitted when a VoiceChannel updates its start time.

Inheritance

Properties

channel → PartialChannel
The affected VoiceChannel.
no setter
channelId → Snowflake
The ID of the affected VoiceChannel.
final
gateway → Gateway
The gateway that handled this event.
finalinherited
guild → PartialGuild
The Guild containing the channel.
no setter
guildId → Snowflake
The ID of the Guild containing the channel.
final
hashCode → int
The hash code for this object.
no setterinherited
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The time at which the voice session started.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited