VoiceStateUpdateEvent class Events

Emitted when a user's voice state is updated.

Inheritance

Properties

gateway → Gateway
The gateway that handled this event.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
oldState → VoiceState?
The voice state as it was cached before the update.
final
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → VoiceState
The updated voice state.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited