Models topic
This topic contains classes that represent a structure returned by the Discord API.
All models are immutable. To construct your own models to send to the API, see the Builders topic.
To obtain instances of models by making HTTP requests to the API, see the Managers topic.
Classes
- ActionMetadata Models
- Additional metadata associated with an AutoModerationAction.
- ActionRowComponent Models
- A Component that contains multiple child Components.
- Activity Models
- A Rich Presence activity.
- ActivityAssets Models
- Information about an Activity's displayed assets.
- ActivityButton Models
- A button displayed in an activity.
- ActivityParty Models
- Information about an Activity's party.
- ActivitySecrets Models
- Information about an Activity's secrets.
- ActivityTimestamps Models
- Information about an Activity's timings.
- AnnouncementThread Entities Models
- Application Entities Models
- An OAuth2 application.
- ApplicationCommand Entities Models
- A command that can be executed by users and is displayed in the Discord client UI.
- ApplicationCommandInteraction Models
- An application command interaction.
- ApplicationCommandInteractionData Models
- The data sent in an ApplicationCommandInteraction or an ApplicationCommandAutocompleteInteraction.
- ApplicationIntegrationTypeConfiguration Models
- ApplicationRoleConnection Models
- A role connection an application has attached to a user.
- ApplicationRoleConnectionMetadata Models
- Metadata for an app's role connections.
- Attachment Models
- An attachment in a Message.
- AuditLogChange Models
- A change to an object's field in an AuditLogEntry.
- AuditLogEntry Entities Models
- An entry in a Guild's audit log.
- AuditLogEntryInfo Models
- Extra information associated with an AuditLogEntry.
- AutoModerationAction Models
- Describes an action to take when an AutoModerationRule is triggered.
- AutoModerationRule Entities Models
- A rule use for auto-moderation in a Guild.
- AvatarDecorationData Models
- The data for the user's avatar decoration.
- Ban Models
- A ban in a Guild.
- BulkBanResponse Models
- ButtonComponent Models
- A clickable button.
- Channel Entities Models
- A channel of any type.
- ChannelMention Models
- A channel mentioned in a Message.
- ClientStatus Models
- The status of a client on multiple platforms.
- CommandOption Models
- An option in an ApplicationCommand with a type of ApplicationCommandType.chatInput.
- CommandOptionChoice Models
- A choice for a CommandOption.
- CommandPermission Models
- The permission for a role, user or channel to use an ApplicationCommand.
- CommandPermissions Entities Models
- The permissions for an ApplicationCommand in a guild.
- Component Models
- A component in a Message.
- Connection Models
- A link to an account on a service other than Discord.
- ContainerComponent Models
- A component that contains several other components.
- DefaultReaction Models
- The emoji to show in the add reaction button on a thread in a ChannelType.guildForum or a ChannelType.guildMedia channel.
- DirectoryChannel Entities Models
- A directory channel.
- DiscordColor Models
- A 24-bit RGB color.
- DmChannel Entities Models
- A DM channel.
- Embed Models
- Rich content that can be embedded into a message, such as a video, image or custom text.
- EmbedAuthor Models
- An author for an Embed.
- EmbedField Models
- A field in an Embed.
- A footer in an Embed.
- EmbedImage Models
- An image in an Embed.
- EmbedProvider Models
- A provider for an Embed.
- EmbedThumbnail Models
- A thumbnail in an Embed.
- EmbedVideo Models
- A video in an Embed.
- Emoji Entities Models
-
An emoji. Either a TextEmoji, an
ApplicationEmojior a GuildEmoji. - Entitlement Entities Models
- Premium access a user or guild has for an application.
- EntityMetadata Models
- Additional metadata associated with a ScheduledEvent.
- FileComponent Models
- A component that displays a downloadable file.
- FileUploadComponent Models
- FollowedChannel Models
- Information about a channel which has been followed.
- ForumChannel Entities Models
- A forum channel.
- ForumTag Models
- A tag in a forum channel.
- GatewayBot Gateway Models
- Information about how to connect to the Gateway, with client-specific information.
- GatewayConfiguration Models
- Information about how to connect to the Gateway.
- GlobalSticker Entities Models
- A sticker that can be sent in messages. Represents global stickers (default stickers)
- GroupDmChannel Entities Models
- A DM channel with multiple recipients.
- Guild Entities Models
- A collection of channels & users.
- GuildAnnouncementChannel Entities Models
- An announcement channel in a Guild.
- GuildCategory Entities Models
- A category for organizing other Channels in a Guild.
- GuildChannel Entities Models
- A channel in a Guild.
- GuildEmoji Entities Models
- A custom guild emoji.
- GuildMediaChannel Entities Models
- A channel in a guild in which threads can be posted, similarly to a ForumChannel.
- GuildPreview Entities Models
- A preview of a Guild.
- GuildStageChannel Entities Models
- A stage channel.
- GuildSticker Entities Models
- A sticker that can be sent in messages. Represent stickers added to guild
- GuildTemplate Models
- A snapshot of a Guild that can be used to create a new guild.
- GuildTextChannel Entities Models
- A TextChannel in a Guild.
- GuildVoiceChannel Entities Models
- A VoiceChannel in a Guild.
- GuildWidget Models
- A Guild's widget.
- HasThreadsChannel Entities Models
- A channel which can have threads.
- IncidentsData Models
- InstallationParameters Models
- Configuration for an Application's authorization link.
- Integration Entities Models
- An integration in a Guild.
- IntegrationAccount Models
- Information about an integration's account.
- IntegrationApplication Models
- Information about an integration's application.
-
Interaction<
T> Models - An interaction sent by Discord when a user interacts with an ApplicationCommand, a Component or a ModalBuilder.
- InteractionCallback Models
- An interaction callback.
- InteractionCallbackActivityInstanceResource Models
- InteractionCallbackResponse Models
- An interaction callback response.
- InteractionOption Models
- The value of a command option passed in an ApplicationCommandInteraction.
- InteractionResource Models
- An interaction resource.
- Invite Models
- An invite to a Guild or Channel. If the invite is to a Channel, this will be a GroupDmChannel.
- InviteTargetsJobStatus Models
- The status of processing the target users for an invite.
- InviteWithMetadata Models
- MediaGalleryComponent Models
- A component that displays several child media items.
- MediaGalleryItem Models
- An item in a MediaGalleryComponent.
- Member Entities Models
- The representation of a User in a Guild.
- Message Entities Models
- Represents a message sent in a TextChannel.
- MessageActivity Models
- Activity data for rich presence related messages.
- MessageAuthor Models
- An author of a message.
- MessageCall Models
- Information about a call in a private channel.
- MessageComponentInteraction Models
- A message component interaction.
- MessageComponentInteractionData Models
- The data sent in a MessageComponentInteraction.
- MessageInteraction Models
- Information about an interaction associated with a message.
- MessageInteractionMetadata Models
- Metadata about the interaction, including the source of the interaction and relevant server and user IDs.
- MessagePin Models
- Information about a pinned message.
- MessageReference Models
- A reference to an external entity contained in a message.
- MessageSearchResult Models
- The result of searching for messages within a Guild.
- MessageSnapshot Models
- A limited set of fields of a Message.
- ModalSubmitInteraction Models
- A modal submit interaction.
- ModalSubmitInteractionData Models
- The data sent in a ModalSubmitInteraction.
- OAuth2Information Models
- Onboarding Models
- The configuration for a Guild's onboarding process.
- OnboardingPrompt Models
- A prompt in an Onboarding flow.
- OnboardingPromptOption Models
- An option in an OnboardingPrompt.
- PartialThreadMember Models
- A partial ThreadMember.
- PermissionOverwrite Models
- A set of overwrites to apply to permissions within a specific channel.
- PingInteraction Models
- A ping interaction.
- PinList Models
- A list of MessagePins.
- Poll Models
- The poll object has a lot of levels and nested structures. It was also designed to support future extensibility, so some fields may appear to be more complex than necessary.
- PollAnswer Models
- The PollAnswer.id is a number that labels each answer. As an implementation detail, it currently starts at 1 for the first answer and goes up sequentially. We recommend against depending on this sequence.
- PollAnswerCount Models
- PollMedia Models
- The poll media object is a common object that backs both the question and answers. The intention is that it allows us to extensibly add new ways to display things in the future. For now, Poll.question only supports PollMedia.text, while answers can have an optional PollMedia.emoji.
- PollResults Models
-
In a nutshell, this contains the number of votes for each answer.
Due to the intricacies of counting at scale, while a poll is in progress the results may not be perfectly accurate.
They usually are accurate, and shouldn't deviate significantly -- it's just difficult to make guarantees.
To compensate for this, after a poll is finished there is a background job which performs a final, accurate tally of votes.
This tally has concluded once PollResults.isFinalized is
true. If PollResults.answerCounts does not contain an entry for a particular answer, then there are no votes for that answer. - PrivateThread Entities Models
- A private Thread channel.
- PublicThread Entities Models
- A public Thread channel.
- Reaction Models
- A reaction to a message.
- ReactionCountDetails Models
- Details about a Reaction's Reaction.count.
- RecurrenceRule Models
- Indicates how often a ScheduledEvent should recur.
- RecurrenceRuleNWeekday Models
- The week and weekday on which a ScheduledEvent recurs.
- RequestGuildMemberRateLimitedMetadata Models
- Additional information about a rate limited Opcode.requestGuildMembers Gateway request.
- ResolvedData Models
- A mapping of IDs to entities.
- Role Entities Models
- A role in a Guild.
- RoleColors Models
- The colors for the Role.
- RoleSubscriptionData Models
- Information about a role subscription.
- RoleTags Models
- Additional metadata associated with a role.
- ScheduledEvent Entities Models
- A scheduled event in a Guild.
- ScheduledEventUser Models
- A user that has followed a ScheduledEvent.
- SectionComponent Models
- A section in a message, with small accessory component.
- SelectMenuComponent Models
- A dropdown menu in which users can select from on or more choices.
- SelectMenuDefaultValue Models
- A default value in a SelectMenuComponent.
- SelectMenuOption Models
- An option in a SelectMenuComponent.
- SeparatorComponent Models
- A component that introduces space between two other components.
- SessionStartLimit Models
- Information about a client's session start limits.
- Sku Entities Models
- A premium offering that can be made available to your application's users or guilds.
- Snowflake Core Models
- A unique ID used to identify objects in the API.
- SoundboardSound Entities Models
- StageInstance Entities Models
- Information about a live stage.
- StickerItem Entities Models
- A representation of a sticker with minimal information
- StickerPack Entities Models
- A Sticker Pack -- group of stickers that are gated behind Nitro.
- SubmittedActionRowComponent Models
- An ActionRowComponent received in an Interaction.
- SubmittedCheckboxComponent Models
- SubmittedCheckboxGroupComponent Models
- SubmittedComponent Models
- A component received as part of an Interaction.
- SubmittedFileUploadComponent Models
- SubmittedLabelComponent Models
- A label received in an Interaction.
- SubmittedRadioGroupComponent Models
- SubmittedSelectMenuComponent Models
- A SelectMenuComponent received in an Interaction.
- SubmittedTextDisplayComponent Models
- A TextDisplayComponent received in an Interaction.
- SubmittedTextInputComponent Models
- A text input received in an Interaction.
- Subscription Entities Models
- A subscription to an Sku.
- Team Models
- A group of developers.
- TeamMember Models
- A member of a Team.
- TextChannel Entities Models
- / A text channel
- TextDisplayComponent Models
- A component that displays text.
- TextEmoji Entities Models
-
A text emoji, such as
❤️. - TextInputComponent Models
- A text field in a modal.
- Thread Entities Models
- A thread channel.
- ThreadList Models
- A list of threads and thread members.
- ThreadMember Models
- Additional information associated with a Member in a Thread.
- ThreadsOnlyChannel Entities Models
- ThumbnailComponent Models
- A component that shows a small image.
- TriggerMetadata Models
- Additional metadata associated with the trigger for an AutoModerationRule.
- UnfurledMediaItem Models
- UnknownComponent Models
- An unknown component.
- UnknownInteraction Models
- An unknown interaction.
- UnknownRateLimitedMetadata Models
- Unparsed information about a rate limited Gateway request.
- User Entities Models
- A single user, outside of a Guild's context.
- UserGuild Entities Models
- A collection of channels & users.
- UserPrimaryGuild Models
- VoiceChannel Entities Models
- A voice channel.
- VoiceRegion Models
- A voice region.
- VoiceState Models
- A user's voice connection state.
- Webhook Entities Models
- A non authenticated way to send messages to a Discord channel.
- WebhookAuthor Models
- A partial Webhook sent as part of a Message.
- WelcomeScreen Models
- The configuration for the welcome screen in a guild.
- WelcomeScreenChannel Models
- A channel shown in a WelcomeScreen.
- WidgetSettings Models
- The settings for a Guild's widget.