MessageCall class Models
Information about a call in a private channel.
Properties
- endedAt → DateTime?
-
The time at which the call ended.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manager → MessageManager
-
The manager for this MessageCall.
final
-
participantIds
→ List<
Snowflake> -
The IDs of the users in the call.
final
-
participants
→ List<
PartialUser> -
The users in the call.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited