ThreadUpdateBuilder class Builders
- Inheritance
-
- Object
- Builder<
Thread> - UpdateBuilder<
Thread> - ThreadUpdateBuilder
Constructors
Properties
-
appliedTags
↔ List<
Snowflake> ? -
The IDs of the set of tags that have been applied to a thread in a ChannelType.guildForum channel.
getter/setter pair
- autoArchiveDuration ↔ Duration?
-
Default duration, copied onto newly created threads, in minutes, threads will stop showing in the channel list after the specified period of inactivity.
getter/setter pair
-
flags
↔ Flags<
ChannelFlags> ? -
Channel flags combined.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isArchived ↔ bool?
-
Whether the thread is archived.
getter/setter pair
- isInvitable ↔ bool?
-
Whether non-moderators can add other non-moderators to a thread; only available on private threads.
getter/setter pair
- isLocked ↔ bool?
-
Whether the thread is locked; only available on private threads.
getter/setter pair
- name ↔ String?
-
The name of the thread.
getter/setter pair
- rateLimitPerUser ↔ Duration?
-
The duration after which the user will be able to send another message (0-21600 seconds). Members with the Permissions.manageMessages
or Permissions.manageChannels permission are unaffected.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited