UserPrimaryGuild class Models
Properties
- badge → CdnAsset?
-
The server tag as an asset.
no setter
- badgeHash → String?
-
The server tag badge hash.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifyGuild → PartialGuild?
-
The guild of this user's primary guild.
no setter
- identityGuildId → Snowflake?
-
The id of this user's primary guild.
final
- isIdentityEnabled → bool?
-
Whether the user is displaying their primary guild tag.
final
- manager → UserManager
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
The text of the user's server tag. Limited to 4 characters.
final
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited