Managers topic

Managers provide deserialization and Dart APIs that correspond to Discord's HTTP endpoints. Each Manager is usually responsible for one or more kind of Entity and will provide parsing for Models related to that Entity. Some managers may not manage a specific kind of Entity and instead will simply wrap a group of related HTTP endpoints.

Managers also provide Caches for the Entities they manage. These can be accessed using Manager.cache and Manager.get.

Managers usually expose at least the following APIs:

  • Manager.get to fetch an entity using the cache if possible.
  • Manager.fetch to fetch an entity while bypassing the cache.
  • Manager.parse to parse a JSON map to an entity (usually only called internally by nyxx).

Managers that are not ReadOnlyManagers also expose the following APIs:

Most managers will expose additional methods specific to the type of entity they manage.

Managers that support creation and updating will use Builders to specify how the entity should be created or updated.

Many manager methods can be accessed directly on partial Entities, often leading to cleaner code. For more information, see the Entities topic.

Classes

ApplicationCommandManager Managers
A Manager for ApplicationCommands.
ApplicationEmojiManager Managers
ApplicationManager Managers
A manager for Applications.
AuditLogManager Managers
AutoModerationManager Managers
ChannelManager Managers
A manager for Channels.
EmojiManager Managers
EntitlementManager Managers
A Manager for Entitlements.
GatewayManager Gateway Managers
A Manager for gateway information.
GlobalApplicationCommandManager Managers
An ApplicationCommandManager for an application's global commands.
GlobalSoundboardManager Managers
GlobalStickerManager Managers
GuildApplicationCommandManager Managers
An ApplicationCommandManager for the commands in a guild.
GuildEmojiManager Managers
GuildManager Managers
A manager for Guilds.
GuildSoundboardManager Managers
A Manager for guild SoundboardSounds.
GuildStickerManager Managers
IntegrationManager Managers
A Manager for Integrations.
InteractionManager Managers
A Manager for Interactions.
InviteManager Managers
A manager for Invites.
Manager<T extends WritableSnowflakeEntity<T>> Core Managers
Provides the means to interact with the API for a given entity type.
MemberManager Managers
A manager for Members.
MessageManager Managers
A manager for Messages in a TextChannel.
ReadOnlyManager<T extends ManagedSnowflakeEntity<T>> Core Managers
A Manager that provides only read access to the API.
RoleManager Managers
A manager for Roles.
ScheduledEventManager Managers
A Manager for ScheduledEvents.
SkuManager Managers
SoundboardManager Managers
SubscriptionManager Managers
UserManager Managers
A manager for Users.
VoiceManager Managers
A manager for VoiceStates.
WebhookManager Managers
A manager for Webhooks.